@@ -25,11 +25,12 @@ import tempfile
 from io import StringIO
 
 import pytest
-from frosted.api import check_path, check_recursive
-from frosted.messages import UnusedImport, PythonSyntaxError
-from frosted.reporter import Reporter
 from pies.overrides import *
 
+from frosted.api import check_path, check_recursive
+from frosted.messages import PythonSyntaxError, UnusedImport
+from frosted.reporter import Reporter
+
 from .utils import LoggingReporter, Node
 
 
