@@ -5,9 +5,10 @@ from __future__ import absolute_import, division, print_function, unicode_litera
 from sys import version_info
 
 import pytest
-from frosted import messages as m
 from pies.overrides import *
 
+from frosted import messages as m
+
 from .utils import flakes
 
 
@@ -857,7 +858,7 @@ def test_augmentedAssignmentImportedFunctionCall():
 
 @pytest.mark.skipif('''version_info < (3, 3)''')
 def test_yieldFromUndefined():
-    """Test C{yield from} statement."""
+    """Test yield from statement."""
     flakes('''
     def bar():
         yield from foo()
@@ -874,3 +875,12 @@ def test_bareExcept():
         except:
             pass
         ''', m.BareExcept)
+
+
+def test_access_debug():
+    """Test accessing __debug__ returns no errors"""
+    flakes('''
+    if __debug__:
+        print("success!")
+        print(__debug__)
+    ''')
